@@ -38,6 +38,7 @@ from lightning.app.cli.commands.cp import cp
 from lightning.app.cli.commands.logs import logs
 from lightning.app.cli.commands.ls import ls
 from lightning.app.cli.commands.pwd import pwd
+from lightning.app.cli.commands.rm import rm
 from lightning.app.cli.connect.app import (
     _list_app_commands,
     _retrieve_connection_to_an_app,
@@ -144,6 +145,7 @@ _main.command(hidden=True)(ls)
 _main.command(hidden=True)(cd)
 _main.command(hidden=True)(cp)
 _main.command(hidden=True)(pwd)
+_main.command(hidden=True)(rm)
 show.command()(logs)
 
 
