@@ -1,3 +1,17 @@
+# Copyright The Lightning AI team.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import warnings
 from typing import Any, Type
 
@@ -56,17 +70,17 @@ class MultiNode(LightningFlow):
         """
         super().__init__()
         if num_nodes > 1 and not is_running_in_cloud():
-            num_nodes = 1
             warnings.warn(
                 f"You set {type(self).__name__}(num_nodes={num_nodes}, ...)` but this app is running locally."
                 " We assume you are debugging and will ignore the `num_nodes` argument."
                 " To run on multiple nodes in the cloud, launch your app with `--cloud`."
             )
+            num_nodes = 1
         self.ws = structures.List(
             *[
                 work_cls(
                     *work_args,
-                    cloud_compute=cloud_compute,
+                    cloud_compute=cloud_compute.clone(),
                     **work_kwargs,
                     parallel=True,
                 )
