@@ -1,4 +1,19 @@
+# Copyright The Lightning AI team.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import abc
+import asyncio
 import base64
 import os
 import platform
@@ -252,19 +267,19 @@ class PythonServer(LightningWork, abc.ABC):
         return out
 
     def _attach_predict_fn(self, fastapi_app: FastAPI) -> None:
-        from torch import inference_mode, no_grad
-
         input_type: type = self.configure_input_type()
         output_type: type = self.configure_output_type()
 
-        device = _get_device()
-        context = no_grad if device.type == "mps" else inference_mode
+        def predict_fn_sync(request: input_type):  # type: ignore
+            return self.predict(request)
 
-        def predict_fn(request: input_type):  # type: ignore
-            with context():
-                return self.predict(request)
+        async def async_predict_fn(request: input_type):  # type: ignore
+            return await self.predict(request)
 
-        fastapi_app.post("/predict", response_model=output_type)(predict_fn)
+        if asyncio.iscoroutinefunction(self.predict):
+            fastapi_app.post("/predict", response_model=output_type)(async_predict_fn)
+        else:
+            fastapi_app.post("/predict", response_model=output_type)(predict_fn_sync)
 
     def get_code_sample(self, url: str) -> Optional[str]:
         input_type: Any = self.configure_input_type()
