@@ -1,3 +1,17 @@
+# Copyright The Lightning AI team.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import sys
 import time
 import warnings
@@ -329,7 +343,7 @@ class LightningWork:
 
     @property
     def has_stopped(self) -> bool:
-        """Return whether the work has started."""
+        """Return whether the work has stopped."""
         return self.status.stage == WorkStageStatus.STOPPED
 
     @property
