@@ -1,3 +1,17 @@
+# Copyright The Lightning AI team.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import json
 import queue
 from dataclasses import dataclass
@@ -79,7 +93,7 @@ def _app_logs_reader(
 
     # And each socket on separate thread pushing log event to print queue
     #   run_forever() will run until we close() the connection from outside
-    log_threads = [Thread(target=work.run_forever) for work in log_sockets]
+    log_threads = [Thread(target=work.run_forever, daemon=True) for work in log_sockets]
 
     # Establish connection and begin pushing logs to the print queue
     for th in log_threads:
