@@ -1,3 +1,17 @@
+# Copyright The Lightning AI team.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import errno
 import inspect
 import os
@@ -17,6 +31,7 @@ from pydantic import BaseModel
 
 from lightning.app.api.http_methods import Post
 from lightning.app.api.request_types import _APIRequest, _CommandRequest, _RequestResponse
+from lightning.app.core.plugin import Plugin
 from lightning.app.utilities import frontend
 from lightning.app.utilities.app_helpers import is_overridden, Logger
 from lightning.app.utilities.cloud import _get_project
@@ -94,7 +109,7 @@ def _download_command(
     app_id: Optional[str] = None,
     debug_mode: bool = False,
     target_file: Optional[str] = None,
-) -> ClientCommand:
+) -> Union[ClientCommand, Plugin]:
     # TODO: This is a skateboard implementation and the final version will rely on versioned
     # immutable commands for security concerns
     command_name = command_name.replace(" ", "_")
@@ -107,7 +122,7 @@ def _download_command(
     if not debug_mode:
         if app_id:
             if not os.path.exists(target_file):
-                client = LightningClient()
+                client = LightningClient(retry=False)
                 project_id = _get_project(client).project_id
                 response = client.lightningapp_instance_service_list_lightningapp_instance_artifacts(
                     project_id=project_id, id=app_id
@@ -125,7 +140,13 @@ def _download_command(
     mod = module_from_spec(spec)
     sys.modules[cls_name] = mod
     spec.loader.exec_module(mod)
-    command = getattr(mod, cls_name)(method=None)
+    command_type = getattr(mod, cls_name)
+    if issubclass(command_type, ClientCommand):
+        command = command_type(method=None)
+    elif issubclass(command_type, Plugin):
+        command = command_type()
+    else:
+        raise ValueError(f"Expected class {cls_name} for command {command_name} to be a `ClientCommand` or `Plugin`.")
     if tmpdir and os.path.exists(tmpdir):
         shutil.rmtree(tmpdir)
     return command
@@ -168,12 +189,11 @@ def _validate_client_command(command: ClientCommand):
             )
 
 
-def _upload_command(command_name: str, command: ClientCommand) -> Optional[str]:
+def _upload(name: str, prefix: str, obj: Any) -> Optional[str]:
     from lightning.app.storage.path import _filesystem, _is_s3fs_available, _shared_storage_path
 
-    command_name = command_name.replace(" ", "_")
-    filepath = f"commands/{command_name}.py"
-    remote_url = str(_shared_storage_path() / "artifacts" / filepath)
+    name = name.replace(" ", "_")
+    filepath = f"{prefix}/{name}.py"
     fs = _filesystem()
 
     if _is_s3fs_available():
@@ -182,7 +202,7 @@ def _upload_command(command_name: str, command: ClientCommand) -> Optional[str]:
         if not isinstance(fs, S3FileSystem):
             return
 
-        source_file = str(inspect.getfile(command.__class__))
+        source_file = str(inspect.getfile(obj.__class__))
         remote_url = str(_shared_storage_path() / "artifacts" / filepath)
         fs.put(source_file, remote_url)
         return filepath
@@ -197,13 +217,25 @@ def _prepare_commands(app) -> List:
     for command_mapping in commands:
         for command_name, command in command_mapping.items():
             if isinstance(command, ClientCommand):
-                _upload_command(command_name, command)
+                _upload(command_name, "commands", command)
 
     # 2: Cache the commands on the app.
     app.commands = commands
     return commands
 
 
+def _prepare_plugins(app) -> List:
+    if not is_overridden("configure_plugins", app.root):
+        return []
+
+    # 1: Upload the plugins to s3.
+    plugins = app.root.configure_plugins()
+    for plugin_mapping in plugins:
+        for plugin_name, plugin in plugin_mapping.items():
+            if isinstance(plugin, Plugin):
+                _upload(plugin_name, "plugins", plugin)
+
+
 def _process_api_request(app, request: _APIRequest):
     flow = app.get_component_by_name(request.name)
     method = getattr(flow, request.method_name)
