@@ -11,12 +11,27 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
+import sys
 from typing import Any
 
 from lightning.pytorch.callbacks import ModelCheckpoint
 
 
+def _patch_sys_modules() -> None:
+    # TODO: Remove in v2.0.0
+    self = sys.modules[__name__]
+    sys.modules["lightning.pytorch.callbacks.base"] = self
+
+
+class Callback:
+    # TODO: Remove in v2.0.0
+    def __init__(self, *_: Any, **__: Any) -> None:
+        raise NotImplementedError(
+            "Importing `lightning.pytorch.callbacks.base.Callback` was deprecated in v1.7.0 and removed as of"
+            " v1.9.0. Please use `from lightning.pytorch import Callback` instead"
+        )
+
+
 def _save_checkpoint(_: ModelCheckpoint, __: Any) -> None:
     # TODO: Remove in v2.0.0
     raise NotImplementedError(
@@ -25,5 +40,7 @@ def _save_checkpoint(_: ModelCheckpoint, __: Any) -> None:
     )
 
 
+_patch_sys_modules()
+
 # Methods
 ModelCheckpoint.save_checkpoint = _save_checkpoint
