@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,8 +15,8 @@ from typing import Any, Dict, List, Union
 
 import torch
 
-from lightning.lite.accelerators.cpu import _parse_cpu_cores
-from lightning.lite.utilities.types import _DEVICE
+from lightning.fabric.accelerators.cpu import _parse_cpu_cores
+from lightning.fabric.utilities.types import _DEVICE
 from lightning.pytorch.accelerators.accelerator import Accelerator
 from lightning.pytorch.utilities.exceptions import MisconfigurationException
 from lightning.pytorch.utilities.imports import _PSUTIL_AVAILABLE
