@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,7 +21,7 @@ import os
 from typing import Any
 
 import lightning.pytorch as pl
-from lightning.lite.utilities.types import _PATH
+from lightning.fabric.utilities.types import _PATH
 from lightning.pytorch.callbacks import Checkpoint
 
 
