@@ -147,7 +147,7 @@ class FitLoop(Loop[None]):
         raise RuntimeError("`FitLoop._results` property isn't defined. Accessed outside of scope")
 
     @property
-    def _should_stop_early(self) -> bool:
+    def _can_stop_early(self) -> bool:
         met_min_epochs = self.epoch_progress.current.processed >= self.min_epochs if self.min_epochs else True
         met_min_steps = self.epoch_loop.global_step >= self.min_steps if self.min_steps else True
         return met_min_epochs and met_min_steps
@@ -175,7 +175,7 @@ class FitLoop(Loop[None]):
             rank_zero_info(f"`Trainer.fit` stopped: `max_epochs={self.max_epochs!r}` reached.")
             return True
 
-        if self.trainer.should_stop and self._should_stop_early:
+        if self.trainer.should_stop and self._can_stop_early:
             rank_zero_debug("`Trainer.fit` stopped: `trainer.should_stop` was set.")
             return True
 
