@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from lightning.lite.strategies.registry import _StrategyRegistry
+from lightning.fabric.strategies.registry import _StrategyRegistry
 from lightning.pytorch.strategies.bagua import BaguaStrategy  # noqa: F401
 from lightning.pytorch.strategies.colossalai import ColossalAIStrategy  # noqa: F401
 from lightning.pytorch.strategies.ddp import DDPStrategy  # noqa: F401
