@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,9 +18,9 @@ from typing import Any, Callable, Optional
 import torch.multiprocessing as mp
 
 import lightning.pytorch as pl
-from lightning.lite.accelerators.tpu import _XLA_AVAILABLE
-from lightning.lite.strategies.launchers.xla import _rank_teardown
-from lightning.lite.utilities import move_data_to_device
+from lightning.fabric.accelerators.tpu import _XLA_AVAILABLE
+from lightning.fabric.strategies.launchers.xla import _rank_teardown
+from lightning.fabric.utilities import move_data_to_device
 from lightning.pytorch.strategies.launchers.multiprocessing import (
     _FakeQueue,
     _GlobalStateSnapshot,
