@@ -273,6 +273,14 @@ class AcceleratorConnector:
                     " you can use `Trainer(strategy='ddp_spawn', accelerator='tpu')` instead."
                 )
 
+        if strategy is not None and strategy not in self._registered_strategies and not isinstance(strategy, Strategy):
+            raise ValueError(
+                f"You selected an invalid strategy name: `strategy={strategy!r}`."
+                " It must be either a string or an instance of `lightning.pytorch.strategies.Strategy`."
+                " Example choices: ddp, ddp_spawn, deepspeed, dp, ..."
+                " Find a complete list of options in our documentation at https://lightning.ai"
+            )
+
         if (
             accelerator is not None
             and accelerator not in self._accelerator_types
@@ -694,13 +702,13 @@ class AcceleratorConnector:
             # handle horovod has to happen before initialize strategy because HorovodStrategy needs hvd.init() first.
             # TODO lazy initialized and setup horovod strategy `global_rank`
             self._handle_horovod()
+        # The validation of `_strategy_flag` already happened earlier on in the connector
+        assert isinstance(self._strategy_flag, (str, Strategy))
         if isinstance(self._strategy_flag, str):
             self.strategy = StrategyRegistry.get(self._strategy_flag)
-        elif isinstance(self._strategy_flag, Strategy):
+        else:
             # TODO(fabric): remove ignore after merging Fabric and PL strategies
             self.strategy = self._strategy_flag  # type: ignore[assignment]
-        else:
-            raise RuntimeError(f"{self.strategy} is not valid type: {self.strategy}")
 
     def _check_and_init_precision(self) -> PrecisionPlugin:
         self._validate_precision_choice()
