@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -46,6 +46,7 @@ from typing_extensions import Literal
 import lightning.pytorch as pl
 from lightning.fabric.utilities.cloud_io import get_filesystem
 from lightning.fabric.utilities.data import _auto_add_worker_init_fn
+from lightning.fabric.utilities.imports import _TORCH_GREATER_EQUAL_2_0
 from lightning.fabric.utilities.types import _PATH
 from lightning.fabric.utilities.warnings import PossibleUserWarning
 from lightning.pytorch.accelerators import Accelerator, TPUAccelerator
@@ -175,7 +176,7 @@ class Trainer:
 
         Args:
 
-            accelerator: Supports passing different accelerator types ("cpu", "gpu", "tpu", "ipu", "hpu", "mps, "auto")
+            accelerator: Supports passing different accelerator types ("cpu", "gpu", "tpu", "ipu", "hpu", "mps", "auto")
                 as well as custom accelerator instances.
 
             accumulate_grad_batches: Accumulates grads every k batches or as set up in the dict.
@@ -561,19 +562,20 @@ class Trainer:
         self._last_train_dl_reload_epoch = float("-inf")
         self._last_val_dl_reload_epoch = float("-inf")
 
-    def _maybe_unwrap_optimized(self, model: Optional["pl.LightningModule"]) -> Optional["pl.LightningModule"]:
-        if model is None:
-            return None
-
-        try:
-            from torch._dynamo import OptimizedModule
-        except ImportError:
+    def _maybe_unwrap_optimized(self, model: object) -> "pl.LightningModule":
+        if not _TORCH_GREATER_EQUAL_2_0:
+            if not isinstance(model, pl.LightningModule):
+                raise TypeError(f"`model` must be a `LightningModule`, got `{type(model).__qualname__}`")
             return model
+        from torch._dynamo import OptimizedModule
 
-        if not isinstance(model, OptimizedModule):
+        if isinstance(model, OptimizedModule):
+            return model.from_compiled(model)
+        if isinstance(model, pl.LightningModule):
             return model
-
-        return pl.LightningModule.from_compiled(model)
+        raise TypeError(
+            f"`model` must be a `LightningModule` or `torch._dynamo.OptimizedModule`, got `{type(model).__qualname__}`"
+        )
 
     def fit(
         self,
@@ -602,8 +604,6 @@ class Trainer:
             datamodule: An instance of :class:`~lightning.pytorch.core.datamodule.LightningDataModule`.
         """
         model = self._maybe_unwrap_optimized(model)
-        if not isinstance(model, pl.LightningModule):
-            raise TypeError(f"`Trainer.fit()` requires a `LightningModule`, got: {model.__class__.__qualname__}")
         self.strategy._lightning_module = model
         call._call_and_handle_interrupt(
             self, self._fit_impl, model, train_dataloaders, val_dataloaders, datamodule, ckpt_path
@@ -685,10 +685,15 @@ class Trainer:
             :meth:`~lightning.pytorch.core.module.LightningModule.validation_epoch_end`, etc.
             The length of the list corresponds to the number of validation dataloaders used.
         """
-        model = self._maybe_unwrap_optimized(model)
-        if model is not None and not isinstance(model, pl.LightningModule):
-            raise TypeError(f"`Trainer.validate()` requires a `LightningModule`, got: {model.__class__.__qualname__}")
-        self.strategy._lightning_module = model or self.lightning_module
+        if model is None:
+            # do we still have a reference from a previous call?
+            if self.lightning_module is None:
+                raise TypeError(
+                    "`Trainer.validate()` requires a `LightningModule` when it hasn't been passed in a previous run"
+                )
+        else:
+            model = self._maybe_unwrap_optimized(model)
+            self.strategy._lightning_module = model
         return call._call_and_handle_interrupt(
             self, self._validate_impl, model, dataloaders, ckpt_path, verbose, datamodule
         )
@@ -719,12 +724,11 @@ class Trainer:
         if dataloaders is not None and datamodule:
             raise MisconfigurationException("You cannot pass both `trainer.validate(dataloaders=..., datamodule=...)`")
 
-        model_provided = model is not None
-        model = model or self.lightning_module
         if model is None:
-            raise MisconfigurationException(
-                "`model` must be provided to `trainer.validate()` when it hasn't been passed in a previous run"
-            )
+            model = self.lightning_module
+            model_provided = False
+        else:
+            model_provided = True
 
         self.validate_loop.verbose = verbose
 
@@ -778,10 +782,15 @@ class Trainer:
             :meth:`~lightning.pytorch.core.module.LightningModule.test_epoch_end`, etc.
             The length of the list corresponds to the number of test dataloaders used.
         """
-        model = self._maybe_unwrap_optimized(model)
-        if model is not None and not isinstance(model, pl.LightningModule):
-            raise TypeError(f"`Trainer.test()` requires a `LightningModule`, got: {model.__class__.__qualname__}")
-        self.strategy._lightning_module = model or self.lightning_module
+        if model is None:
+            # do we still have a reference from a previous call?
+            if self.lightning_module is None:
+                raise TypeError(
+                    "`Trainer.test()` requires a `LightningModule` when it hasn't been passed in a previous run"
+                )
+        else:
+            model = self._maybe_unwrap_optimized(model)
+            self.strategy._lightning_module = model
         return call._call_and_handle_interrupt(
             self, self._test_impl, model, dataloaders, ckpt_path, verbose, datamodule
         )
@@ -812,12 +821,11 @@ class Trainer:
         if dataloaders is not None and datamodule:
             raise MisconfigurationException("You cannot pass both `trainer.test(dataloaders=..., datamodule=...)`")
 
-        model_provided = model is not None
-        model = model or self.lightning_module
         if model is None:
-            raise MisconfigurationException(
-                "`model` must be provided to `trainer.test()` when it hasn't been passed in a previous run"
-            )
+            model = self.lightning_module
+            model_provided = False
+        else:
+            model_provided = True
 
         self.test_loop.verbose = verbose
 
@@ -872,10 +880,15 @@ class Trainer:
 
         See :ref:`Lightning inference section<deploy/production_basic:Predict step with your LightningModule>` for more.
         """
-        model = self._maybe_unwrap_optimized(model)
-        if model is not None and not isinstance(model, pl.LightningModule):
-            raise TypeError(f"`Trainer.predict()` requires a `LightningModule`, got: {model.__class__.__qualname__}")
-        self.strategy._lightning_module = model or self.lightning_module
+        if model is None:
+            # do we still have a reference from a previous call?
+            if self.lightning_module is None:
+                raise TypeError(
+                    "`Trainer.predict()` requires a `LightningModule` when it hasn't been passed in a previous run"
+                )
+        else:
+            model = self._maybe_unwrap_optimized(model)
+            self.strategy._lightning_module = model
         return call._call_and_handle_interrupt(
             self, self._predict_impl, model, dataloaders, datamodule, return_predictions, ckpt_path
         )
@@ -907,12 +920,11 @@ class Trainer:
         if dataloaders is not None and datamodule:
             raise MisconfigurationException("You cannot pass both `trainer.predict(dataloaders=..., datamodule=...)`")
 
-        model_provided = model is not None
-        model = model or self.lightning_module
         if model is None:
-            raise MisconfigurationException(
-                "`model` must be provided to `trainer.predict()` when it hasn't been passed in a previous run"
-            )
+            model = self.lightning_module
+            model_provided = False
+        else:
+            model_provided = True
 
         # links data to the trainer
         self._data_connector.attach_data(model, predict_dataloaders=dataloaders, datamodule=datamodule)
@@ -965,9 +977,6 @@ class Trainer:
             method: Method to run tuner on. It can be any of ``("fit", "validate", "test", "predict")``.
         """
         model = self._maybe_unwrap_optimized(model)
-        if not isinstance(model, pl.LightningModule):
-            raise TypeError(f"`Trainer.tune()` requires a `LightningModule`, got: {model.__class__.__qualname__}")
-
         Trainer._log_api_event("tune")
 
         with isolate_rng():
